@@ -765,6 +765,7 @@ staining.
             self.manual_threshold,
             self.thresholding_measurement,
             self.two_class_otsu,
+            self.log_transform,
             self.assign_middle_to_foreground,
             self.lower_outlier_fraction,
             self.upper_outlier_fraction,
@@ -1038,7 +1039,11 @@ staining.
                     # Can't run 3-class otsu on only 2 values.
                     threshold_out = skimage.filters.threshold_otsu(block)
                 else:
-                    threshold_out = threshold_method(block, **kwargs)
+                    try: 
+                        threshold_out = threshold_method(block, **kwargs)
+                    except ValueError:
+                        # Drop nbins kwarg when multi-otsu fails. See issue #6324 scikit-image
+                        threshold_out = threshold_method(block)
                 if isinstance(threshold_out, numpy.ndarray):
                     # Select correct bin if running multiotsu
                     threshold_out = threshold_out[bin_wanted]
